==> deepin-calculator_1.0.2.orig.tar.gz: deepin-calculator-1.0.2/CHANGELOG.md <==
## 1.0.2

adjust detail

<a name=""></a>
##  1.0.1 (2017-12-07)


#### Features

*   use fixed fonts for listview. ([aefea6e0](https://github.com/linuxdeepin/deepin-calculator/commit/aefea6e028caf7e1c113a7271eac1a4cd32e4cb5))

#### Bug Fixes

*   precision of the previous answer. ([81ff49a5](https://github.com/linuxdeepin/deepin-calculator/commit/81ff49a5481f8d2f84d02064e19c8d38cbfb9598))



<a name=""></a>
##  1.0.0 (2017-11-30)


#### Bug Fixes

*   listview color. ([744a92a5](https://github.com/linuxdeepin/deepin-calculator/commit/744a92a5fcb0fd146785ddfd84f1a42a219f5389))
*   history text pos. ([dbf187ad](https://github.com/linuxdeepin/deepin-calculator/commit/dbf187ada81094afb8c44b1eeb039d0f8bcf8225))
*   mult dot not error. ([31636fc7](https://github.com/linuxdeepin/deepin-calculator/commit/31636fc754643cd70d993e66abdfbf8f21cd8fcc))
*   inputEdit position ([9e14a700](https://github.com/linuxdeepin/deepin-calculator/commit/9e14a7008440cdf3e008e5dc4f7f76e288a19b72))
*   inputEdit cursor position. ([abf3bbb5](https://github.com/linuxdeepin/deepin-calculator/commit/abf3bbb55cc54e4f3c55aa499550c06cf8538708))
* **background:**  repeated rendering of background color ([80e5de0d](https://github.com/linuxdeepin/deepin-calculator/commit/80e5de0d19d44f1af10822ed92e132d1f250c6ba))
* **config:**  parameter error ([e5e02e73](https://github.com/linuxdeepin/deepin-calculator/commit/e5e02e733d88f484a1ffc4aed649f13c228b056c))
* **inputEdit:**  paired brackets. ([ecee0a7a](https://github.com/linuxdeepin/deepin-calculator/commit/ecee0a7aaa96d3346a9786c29c50a90e2a95bbbc))
* **title:**  use correct icon ([9ee9c185](https://github.com/linuxdeepin/deepin-calculator/commit/9ee9c1850cd2259d60948c415d1f7016daf7300c))

#### Features

*   modify width for listview. ([f4750541](https://github.com/linuxdeepin/deepin-calculator/commit/f4750541a2e3336ae23ef8e807769747d3f8828c))
*   double select ([79cd8bf8](https://github.com/linuxdeepin/deepin-calculator/commit/79cd8bf88fff0978a5db69efe0483b662c7d6f2f))
*   add error font color && upgrade help manual. ([040f338c](https://github.com/linuxdeepin/deepin-calculator/commit/040f338ca9da1557c548eb0172753bf11bd299a0))
*   modify max value of point. ([9bcbec91](https://github.com/linuxdeepin/deepin-calculator/commit/9bcbec9188e3c02bb8b945d28eb13767aaf9ca2e))
*   add thousands separators. ([ead7ec78](https://github.com/linuxdeepin/deepin-calculator/commit/ead7ec7885a7f116d4a07d3b71fcfbbad7587c2e))
*   press mult sign twice trigger pow. ([6e8327f0](https://github.com/linuxdeepin/deepin-calculator/commit/6e8327f085e7b988e15d6c173495e2d87a0abfa6))
*   optimize editor. ([c414f2ff](https://github.com/linuxdeepin/deepin-calculator/commit/c414f2ffe7dfcbe81e7ae130cac6a91fa3bfd572))
*   add help manual. ([0a85e03a](https://github.com/linuxdeepin/deepin-calculator/commit/0a85e03a148220db69195b839a7670099fc4785a))
*   add thousands separators func. ([0c8549d4](https://github.com/linuxdeepin/deepin-calculator/commit/0c8549d4503aea902de6c458fb79b0bee50f843e))
*   add icon install. ([27d3ae91](https://github.com/linuxdeepin/deepin-calculator/commit/27d3ae91b3d128e754f9c7140f9a401b0ff6249d))
*   add service file. ([5c808d89](https://github.com/linuxdeepin/deepin-calculator/commit/5c808d89d30ccc3f90ea584b2dd0333a079a243a))
*   make font size of edit fit text content. ([c4810e41](https://github.com/linuxdeepin/deepin-calculator/commit/c4810e41707da3ff36078a1640645065645212c2))
* **algorithm:**  support percent sign(%) symbolic operation. ([6b714cfc](https://github.com/linuxdeepin/deepin-calculator/commit/6b714cfc00e7f62235a3b8813d469ade71ed4c9a))
* **mainwindow:**
  *  optimize slots. ([3e971c08](https://github.com/linuxdeepin/deepin-calculator/commit/3e971c0894904ace52b4f8e2c1562961f276c309))
  *  use QSignalMapper ([01dc666f](https://github.com/linuxdeepin/deepin-calculator/commit/01dc666fde6c85667a6ad11eeb85ade1b79a68e8))

==> deepin-calculator_1.0.6.orig.tar.gz: deepin-calculator-1.0.6/CHANGELOG.md <==
<a name="1.0.6"></a>
### 1.0.6 (2018-08-12)


+#### Features

*   expression bar shows tooltip. ([2821e409](https://github.com/linuxdeepin/deepin-calculator/commit/2821e40949e3d73be8dbd325d0690546870e74db))

#### Bug Fixes

*   incorrect calculation in some language environments. ([2a3cd90e](https://github.com/linuxdeepin/deepin-calculator/commit/2a3cd90e1e82b821799a7391582d49dc1717952d))



<a name="1.0.5"></a>
### 1.0.5 (2018-07-31)


#### Bug Fixes

*   not set application name ([154bb923](https://github.com/linuxdeepin/deepin-calculator/commit/154bb923d6ec282a2ec0659759042e3221ab305d))

#### Features

*   set window title ([86aa9097](https://github.com/linuxdeepin/deepin-calculator/commit/86aa9097db5655ead4b1ab06733638dcc55f7118))



<a name="1.0.4"></a>
## 1.0.4 (2018-06-12)

*   Update translations.


<a name=""></a>
##  1.0.3 (2018-05-14)


#### Bug Fixes

*   some env garbled ([146bea9e](https://github.com/linuxdeepin/deepin-calculator/commit/146bea9ecd30b8904df4d591780f4ac2539ae745))
*   move to center ([01285734](https://github.com/linuxdeepin/deepin-calculator/commit/01285734c53741d74dad2bf434549dc593b15bdf))
*   move to center ([81fa2c08](https://github.com/linuxdeepin/deepin-calculator/commit/81fa2c08f11d2599aa35ba654d430a4a571b952f))

#### Features

*   support for 0^(1+j). ([62fba07e](https://github.com/linuxdeepin/deepin-calculator/commit/62fba07eb595f2a20a90abc61615fd370d7dd34f))
*   add scrollbar. ([76a1cdd2](https://github.com/linuxdeepin/deepin-calculator/commit/76a1cdd2e318bae48e9d746b08b4658a2917fbc8))



<a name=""></a>
##  1.0.1 (2017-12-07)


#### Features

*   use fixed fonts for listview. ([aefea6e0](https://github.com/linuxdeepin/deepin-calculator/commit/aefea6e028caf7e1c113a7271eac1a4cd32e4cb5))

#### Bug Fixes

*   precision of the previous answer. ([81ff49a5](https://github.com/linuxdeepin/deepin-calculator/commit/81ff49a5481f8d2f84d02064e19c8d38cbfb9598))



<a name=""></a>
##  1.0.0 (2017-11-30)


#### Bug Fixes

*   listview color. ([744a92a5](https://github.com/linuxdeepin/deepin-calculator/commit/744a92a5fcb0fd146785ddfd84f1a42a219f5389))
*   history text pos. ([dbf187ad](https://github.com/linuxdeepin/deepin-calculator/commit/dbf187ada81094afb8c44b1eeb039d0f8bcf8225))
*   mult dot not error. ([31636fc7](https://github.com/linuxdeepin/deepin-calculator/commit/31636fc754643cd70d993e66abdfbf8f21cd8fcc))
*   inputEdit position ([9e14a700](https://github.com/linuxdeepin/deepin-calculator/commit/9e14a7008440cdf3e008e5dc4f7f76e288a19b72))
*   inputEdit cursor position. ([abf3bbb5](https://github.com/linuxdeepin/deepin-calculator/commit/abf3bbb55cc54e4f3c55aa499550c06cf8538708))
* **background:**  repeated rendering of background color ([80e5de0d](https://github.com/linuxdeepin/deepin-calculator/commit/80e5de0d19d44f1af10822ed92e132d1f250c6ba))
* **config:**  parameter error ([e5e02e73](https://github.com/linuxdeepin/deepin-calculator/commit/e5e02e733d88f484a1ffc4aed649f13c228b056c))
* **inputEdit:**  paired brackets. ([ecee0a7a](https://github.com/linuxdeepin/deepin-calculator/commit/ecee0a7aaa96d3346a9786c29c50a90e2a95bbbc))
* **title:**  use correct icon ([9ee9c185](https://github.com/linuxdeepin/deepin-calculator/commit/9ee9c1850cd2259d60948c415d1f7016daf7300c))

#### Features

*   modify width for listview. ([f4750541](https://github.com/linuxdeepin/deepin-calculator/commit/f4750541a2e3336ae23ef8e807769747d3f8828c))
*   double select ([79cd8bf8](https://github.com/linuxdeepin/deepin-calculator/commit/79cd8bf88fff0978a5db69efe0483b662c7d6f2f))
*   add error font color && upgrade help manual. ([040f338c](https://github.com/linuxdeepin/deepin-calculator/commit/040f338ca9da1557c548eb0172753bf11bd299a0))
*   modify max value of point. ([9bcbec91](https://github.com/linuxdeepin/deepin-calculator/commit/9bcbec9188e3c02bb8b945d28eb13767aaf9ca2e))
*   add thousands separators. ([ead7ec78](https://github.com/linuxdeepin/deepin-calculator/commit/ead7ec7885a7f116d4a07d3b71fcfbbad7587c2e))
*   press mult sign twice trigger pow. ([6e8327f0](https://github.com/linuxdeepin/deepin-calculator/commit/6e8327f085e7b988e15d6c173495e2d87a0abfa6))
*   optimize editor. ([c414f2ff](https://github.com/linuxdeepin/deepin-calculator/commit/c414f2ffe7dfcbe81e7ae130cac6a91fa3bfd572))
*   add help manual. ([0a85e03a](https://github.com/linuxdeepin/deepin-calculator/commit/0a85e03a148220db69195b839a7670099fc4785a))
*   add thousands separators func. ([0c8549d4](https://github.com/linuxdeepin/deepin-calculator/commit/0c8549d4503aea902de6c458fb79b0bee50f843e))
*   add icon install. ([27d3ae91](https://github.com/linuxdeepin/deepin-calculator/commit/27d3ae91b3d128e754f9c7140f9a401b0ff6249d))
*   add service file. ([5c808d89](https://github.com/linuxdeepin/deepin-calculator/commit/5c808d89d30ccc3f90ea584b2dd0333a079a243a))
*   make font size of edit fit text content. ([c4810e41](https://github.com/linuxdeepin/deepin-calculator/commit/c4810e41707da3ff36078a1640645065645212c2))
* **algorithm:**  support percent sign(%) symbolic operation. ([6b714cfc](https://github.com/linuxdeepin/deepin-calculator/commit/6b714cfc00e7f62235a3b8813d469ade71ed4c9a))
* **mainwindow:**
  *  optimize slots. ([3e971c08](https://github.com/linuxdeepin/deepin-calculator/commit/3e971c0894904ace52b4f8e2c1562961f276c309))
  *  use QSignalMapper ([01dc666f](https://github.com/linuxdeepin/deepin-calculator/commit/01dc666fde6c85667a6ad11eeb85ade1b79a68e8))
